@@ -61,6 +61,7 @@ use constant INSTALLED_DEPENDENCIES => 18;
 use constant MISSING_DEPENDENCIES => 19;
 use constant CATEGORY_ICON => 20;
 use constant LOCAL_PKG => 21;
+use constant LIBS => 22;
 use constant BUFFER => 30;
 
 use constant STATUS_OK => 0;
@@ -315,6 +316,16 @@ sub BuildDB {
 			@{$newdb{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
 			next;				
 		}
+		if ($_ =~ /PACKAGE REQUIRED:\s*([^\s]*)\s*$/) { 
+			@{$newdb{$soft}}[DEPENDENCIES] = "$1";	
+			@{$newdb{$soft}}[DEPENDENCIES] =~ s/,/ /g ;
+			next;				
+		}
+		if ($_ =~ /PACKAGE LIBS:\s*(.*)$/) { 
+			@{$newdb{$soft}}[LIBS] = "$1";	
+			@{$newdb{$soft}}[LIBS] =~ s/,/ /g ;
+			next;				
+		}				
 		# @{$newdb{$soft}}[DESCRIPTION] = "" if ( undef @{$newdb{$soft}}[DESCRIPTION] ) ;	
 		while ($_ =~ /\Q${soft}\E:(.*)/) {
 			$desc = $1;
@@ -323,7 +334,7 @@ sub BuildDB {
 			@{$newdb{$soft}}[DESCRIPTION] = @{$newdb{$soft}}[DESCRIPTION]." ".$desc;
 			$_ = <SH>;
 		}
-		
+
 		# Until we check local packages, everything is NEW
 		@{$newdb{$soft}}[INSTALLED_VERSION] = decode('utf8',gettext("not installed"));
 		@{$newdb{$soft}}[STATUS] = STATUS_NEW ;
